@@ -60,14 +60,14 @@
 #'  * The batch evaluation is requested at the [TuningInstance] object `instance`,
 #'    so each batch is possibly executed in parallel via [mlr3::benchmark()],
 #'    and all evaluations are stored inside of `instance$bmr`.
-#'  * Before and after the batch evaluation, the [Terminator] is checked, and if it is positive,
+#'  * Before the batch evaluation, the [Terminator] is checked, and if it is positive,
 #'    an exception of class `"terminated_error"` is generated.
 #'    In the later case the current batch of evaluations is still stored in `instance`,
 #'    but the numeric scores are not sent back to the handling optimizer as it has lost execution control.
 #'  * After such an exception was caught we select the best configuration from `instance$bmr` and
 #'    return it.
 #'  * Note that therefore more points than specified by the [Terminator] may be evaluated,
-#'    as the Terminator is only checked before and after a batch evaluation,
+#'    as the Terminator is only checked before a batch evaluation,
 #'    and not in-between evaluation in a batch.
 #'    How many more depends on the setting of the batch size.
 #'  * Overwrite the private super-method `assign_result` if you want to decide yourself how to estimate
@@ -142,6 +142,8 @@ Tuner = R6Class("Tuner",
       }, terminated_error = function(cond) {})
       lg$info("Finished tuning after %i evals", instance$n_evals)
       private$assign_result(instance)
+      lg$info("Tuned x: %s", as_short_string(instance$result$tune_x))
+      lg$info("Tuned y: %s", as_short_string(as.list(instance$result$perf)))
       invisible(NULL)
     }
   ),
